@@ -1,5 +1,7 @@
+### R code from vignette source 'distr.Rnw'
+
 ###################################################
-### chunk number 1: SweaveListingsPreparations
+### code chunk number 1: SweaveListingsPreparations
 ###################################################
 require(SweaveListingUtils)
 SweaveListingPreparations()
@@ -9,7 +11,7 @@ setToBeDefinedPkgs(pkgs = c("distr","distrEx","distrTEst","distrSim",
 
 
 ###################################################
-### chunk number 2: 
+### code chunk number 2: distr.Rnw:223-230
 ###################################################
 ## preparation: set option withSweave to true
 require(distrTEst)
@@ -21,7 +23,7 @@ options("newDevice" = TRUE)
 
 
 ###################################################
-### chunk number 3: exam1
+### code chunk number 3: exam1
 ###################################################
 require(distr)
 N <- Norm(mean = 2, sd = 1.3)
@@ -36,7 +38,7 @@ Zs
 
 
 ###################################################
-### chunk number 4: DiscrDist
+### code chunk number 4: DiscrDist
 ###################################################
 D <- DiscreteDistribution(supp = c(1,5,7,21), prob = c(0.1,0.1,0.6,0.2))
 D
@@ -44,7 +46,7 @@ plot(D)
 
 
 ###################################################
-### chunk number 5: AbscDist
+### code chunk number 5: AbscDist
 ###################################################
 AC <- AbscontDistribution(d = function(x) exp(-abs(x)^3), withStand = TRUE)
 AC
@@ -52,7 +54,7 @@ plot(AC)
 
 
 ###################################################
-### chunk number 6: examLis
+### code chunk number 6: examLis
 ###################################################
 library(distr)
 M1 <- UnivarMixingDistribution(Norm(), Pois(lambda=1), Norm(), 
@@ -62,14 +64,14 @@ M2
 
 
 ###################################################
-### chunk number 7: warningArith
+### code chunk number 7: warningArith
 ###################################################
   A1 <- Norm(); A2 <- Unif()
   A1 + A2
 
 
 ###################################################
-### chunk number 8: examdcP
+### code chunk number 8: examdcP
 ###################################################
 decomposePM(Norm())
      decomposePM(Binom(2,0.3)-Binom(5,.4))
@@ -78,7 +80,7 @@ decomposePM(Norm())
 
 
 ###################################################
-### chunk number 9: examflat
+### code chunk number 9: examflat
 ###################################################
 D1 <- Norm()
 D2 <- Pois(1)
@@ -93,7 +95,7 @@ D0
 
 
 ###################################################
-### chunk number 10: arithmetic
+### code chunk number 10: arithmetic
 ###################################################
   A1 <- Norm(); A2 <- Unif()
   d(sin(A1 + A2))(0.1)
@@ -102,7 +104,7 @@ D0
 
 
 ###################################################
-### chunk number 11: arith2v1
+### code chunk number 11: arith2v1
 ###################################################
   A1 <- Norm(); A2 <- Unif()
   A1A2 <- A1*A2
@@ -110,14 +112,14 @@ D0
 
 
 ###################################################
-### chunk number 12: arith2v2
+### code chunk number 12: arith2v2
 ###################################################
   A12 <- 1/(A2 + .3)
   plot(A12) 
 
 
 ###################################################
-### chunk number 13: arith2v3
+### code chunk number 13: arith2v3
 ###################################################
   B <- Binom(5,.2)+1
   A1B <- A1^B
@@ -125,54 +127,54 @@ D0
 
 
 ###################################################
-### chunk number 14: arith2V4
+### code chunk number 14: arith2V4
 ###################################################
   plot(1.2^A1)
 
 
 ###################################################
-### chunk number 15: arith2v5
+### code chunk number 15: arith2v5
 ###################################################
   plot(B^A1)
 
 
 ###################################################
-### chunk number 16: Hub
+### code chunk number 16: Hub
 ###################################################
 H <- Huberize(Norm(),lower=-1,upper=2)
 plot(H)
 
 
 ###################################################
-### chunk number 17: Trun
+### code chunk number 17: Trun
 ###################################################
 T <- Truncate(Norm(),lower=-1,upper=2)
 plot(T)
 
 
 ###################################################
-### chunk number 18: Min1
+### code chunk number 18: Min1
 ###################################################
 M1 <- Maximum(Unif(0,1), Minimum(Unif(0,1), Unif(0,1)))
 plot(M1)
 
 
 ###################################################
-### chunk number 19: Min2
+### code chunk number 19: Min2
 ###################################################
 M2 <- Minimum(Exp(4),4)
 plot(M2)
 
 
 ###################################################
-### chunk number 20: Min3
+### code chunk number 20: Min3
 ###################################################
 M3 <- Minimum(Norm(2,2), Pois(3))
 plot(M3)
 
 
 ###################################################
-### chunk number 21: TruncExtr
+### code chunk number 21: TruncExtr
 ###################################################
 N <- Norm()
 TN <- Truncate(N, 20,22)
@@ -181,7 +183,7 @@ p(N)(20, lower.tail = FALSE) ## prob that N>=20
 
 
 ###################################################
-### chunk number 22: qrex
+### code chunk number 22: qrex
 ###################################################
 B <- Binom(5,0.5)
 p(B)(3)
@@ -191,7 +193,7 @@ q.r(B)(0.5)
 
 
 ###################################################
-### chunk number 23: probHN
+### code chunk number 23: probHN
 ###################################################
 B0 <- as(Binom(5,0.5),"DiscreteDistribution")
    ## coercion necessary:
@@ -202,7 +204,7 @@ prob(HN)
 
 
 ###################################################
-### chunk number 24: makeAC
+### code chunk number 24: makeAC
 ###################################################
 par(mfrow=c(2,3))
 plot(makeAbscontDistribution(Nbinom(5,.5)),mfColRow=FALSE)
@@ -211,7 +213,7 @@ par(mfrow=c(1,1))
 
 
 ###################################################
-### chunk number 25: getLowUp
+### code chunk number 25: getLowUp
 ###################################################
 getLow(Nbinom(5,0.5))
 getUp(Nbinom(5,0.5))
@@ -220,44 +222,44 @@ getUp(Norm(5,0.5))
 
 
 ###################################################
-### chunk number 26: cauchy1
+### code chunk number 26: cauchy1
 ###################################################
   plot(Cauchy())
 
 
 ###################################################
-### chunk number 27: cauchy2
+### code chunk number 27: cauchy2
 ###################################################
   plot(Cauchy(),xlim=c(-4,4))
 
 
 ###################################################
-### chunk number 28: plotex1
+### code chunk number 28: plotex1
 ###################################################
 plot(Binom(size = 4, prob = 0.3))
 
 
 ###################################################
-### chunk number 29: plotex2
+### code chunk number 29: plotex2
 ###################################################
 plot(Binom(size = 4, prob = 0.3), do.points = FALSE, verticals = FALSE)
 
 
 ###################################################
-### chunk number 30: plotex3
+### code chunk number 30: plotex3
 ###################################################
 plot(Binom(size = 4, prob = 0.3), main = TRUE, inner = FALSE, cex.main = 1.6,
      tmar = 6)
 
 
 ###################################################
-### chunk number 31: plotex4
+### code chunk number 31: plotex4
 ###################################################
 plot(Binom(size = 4, prob = 0.3), cex.points = 1.2, pch = 20, lwd = 2)
 
 
 ###################################################
-### chunk number 32: plotex5
+### code chunk number 32: plotex5
 ###################################################
 B <- Binom(size = 4, prob = 0.3)
 plot(B, col="red", col.points = "green", main = TRUE, col.main="blue",
@@ -265,35 +267,35 @@ plot(B, col="red", col.points = "green", main = TRUE, col.main="blue",
 
 
 ###################################################
-### chunk number 33: plotex6
+### code chunk number 33: plotex6
 ###################################################
 plot(Nbinom(size = 4,prob = 0.3), cex.points = 1.2, pch.u = 20, pch.a = 10)
 
 
 ###################################################
-### chunk number 34: plotex7
+### code chunk number 34: plotex7
 ###################################################
 plot(Chisq(), log = "xy", ngrid = 100)
 
 
 ###################################################
-### chunk number 35: plotex8
+### code chunk number 35: plotex8
 ###################################################
 plot(Norm(), lwd=3, col = "red", ngrid = 200, lty = 3, las = 2)
 
 
 ###################################################
-### chunk number 36: plotex9
+### code chunk number 36: plotex9
 ###################################################
-plot(Norm(), panel.first = grid(), main = "my Distribution: \%A",
-     inner = list(expression(paste(lambda, "-density of \%C(\%P)")), "CDF",
-                  "Pseudo-inverse with param's \%N"),
-     sub = "this plot was correctly generated on \%D",
+plot(Norm(), panel.first = grid(), main = "my Distribution: %A",
+     inner = list(expression(paste(lambda, "-density of %C(%P)")), "CDF",
+                  "Pseudo-inverse with param's %N"),
+     sub = "this plot was correctly generated on %D",
      cex.inner = 0.9, cex.sub = 0.8)
 
 
 ###################################################
-### chunk number 37: plotex10
+### code chunk number 37: plotex10
 ###################################################
 Ch <- Chisq(); setgaps(Ch, exactq = 3)
 plot(Ch, cex = 1.2, pch.u = 20, pch.a = 10, col.points = "green", 
@@ -301,14 +303,14 @@ plot(Ch, cex = 1.2, pch.u = 20, pch.a = 10, col.points = "green",
 
 
 ###################################################
-### chunk number 38: plotex11
+### code chunk number 38: plotex11
 ###################################################
 layout(matrix(c(1,3,2,3), nrow=2))
 plot(N, mfColRow = FALSE)
 
 
 ###################################################
-### chunk number 39: plotex12
+### code chunk number 39: plotex12
 ###################################################
 layout(matrix(c(rep(1,6),2,2,3,3,4,4,5,5,5,6,6,6), 
                    nrow=3, byrow=TRUE))
@@ -317,7 +319,7 @@ plot(HN, mfColRow = FALSE,
 
 
 ###################################################
-### chunk number 40: simulate
+### code chunk number 40: simulate
 ###################################################
 X <- Simulation()
 seed(X) <- setRNG()
@@ -326,7 +328,7 @@ Data(X)[1:10]
 
 
 ###################################################
-### chunk number 41: expectation
+### code chunk number 41: expectation
 ###################################################
 D4 <- LMCondDistribution(theta = 1)
 D4  # corresponds to Norm(cond, 1)
@@ -353,14 +355,14 @@ E(Y)
 
 
 ###################################################
-### chunk number 42: expectationlow
+### code chunk number 42: expectationlow
 ###################################################
 E(Cauchy(), low=3, upp=5)
 var(Cauchy(), low=3, upp=5)
 
 
 ###################################################
-### chunk number 43: expectation2
+### code chunk number 43: expectation2
 ###################################################
 E(N, function(x)x^2) 
 E(N, function(x)x^2,  lowerTruncQuantile = 1e-5)
@@ -369,7 +371,7 @@ var(Cauchy(), low =3, upperTruncQuantile = 1e-10, IQR.fac = 20)
 
 
 ###################################################
-### chunk number 44: var eval=FALSE
+### code chunk number 44: var (eval = FALSE)
 ###################################################
 ##   var <- function(x , ...)
 ##        {dots <- list(...)
@@ -386,7 +388,7 @@ var(Cauchy(), low =3, upperTruncQuantile = 1e-10, IQR.fac = 20)
 
 
 ###################################################
-### chunk number 45: MCEstimator
+### code chunk number 45: MCEstimator
 ###################################################
     library(distrMod)
     x <- rgamma(50, scale = 0.5, shape = 3)
@@ -400,7 +402,7 @@ var(Cauchy(), low =3, upperTruncQuantile = 1e-10, IQR.fac = 20)
 
 
 ###################################################
-### chunk number 46: censPoisFamilyDef eval=FALSE
+### code chunk number 46: censPoisFamilyDef (eval = FALSE)
 ###################################################
 ##     ## search interval for reasonable parameters
 ##     startPar <- function(x,...) c(.Machine$double.eps,max(x))
@@ -411,19 +413,19 @@ var(Cauchy(), low =3, upperTruncQuantile = 1e-10, IQR.fac = 20)
 
 
 ###################################################
-### chunk number 47: PoisFamilyDef eval=FALSE
+### code chunk number 47: PoisFamilyDef (eval = FALSE)
 ###################################################
 ## setClass("PoisFamily", contains = "L2ParamFamily")
 
 
 ###################################################
-### chunk number 48: NormLocationFamily eval=FALSE
+### code chunk number 48: NormLocationFamily (eval = FALSE)
 ###################################################
 ## setClass("NormLocationFamily", contains = "L2LocationFamily")
 
 
 ###################################################
-### chunk number 49: L2ScaleFamily eval=FALSE
+### code chunk number 49: L2ScaleFamily (eval = FALSE)
 ###################################################
 ##  setMethod("validParameter", signature(object = "L2ScaleFamily"),
 ##           function(object, param, tol=.Machine$double.eps){
@@ -435,7 +437,7 @@ var(Cauchy(), low =3, upperTruncQuantile = 1e-10, IQR.fac = 20)
 
 
 ###################################################
-### chunk number 50: GammaFamilyModify eval=FALSE
+### code chunk number 50: GammaFamilyModify (eval = FALSE)
 ###################################################
 ## setMethod("modifyModel", signature(model = "GammaFamily",
 ##            param = "ParamFamParameter"),
@@ -451,14 +453,14 @@ var(Cauchy(), low =3, upperTruncQuantile = 1e-10, IQR.fac = 20)
 
 
 ###################################################
-### chunk number 51: MLEstimator
+### code chunk number 51: MLEstimator
 ###################################################
     MLEstimator(x = x, ParamFamily = G)
     MDEstimator(x = x, ParamFamily = G, distance = KolmogorovDist)
 
 
 ###################################################
-### chunk number 52: NormScaleFam eval=FALSE
+### code chunk number 52: NormScaleFam (eval = FALSE)
 ###################################################
 ## setMethod("mleCalc", signature(x = "numeric", PFam = "NormScaleFamily"),
 ##            function(x, PFam, ...){
@@ -476,7 +478,7 @@ var(Cauchy(), low =3, upperTruncQuantile = 1e-10, IQR.fac = 20)
 
 
 ###################################################
-### chunk number 53: CIex
+### code chunk number 53: CIex
 ###################################################
 require(distrMod)
 ## some transformation
@@ -489,7 +491,7 @@ mtrafo <- function(x){
                      dimnames = list(nms,nms0))                          
      list(fval = fval0, mat = mat0)}
 
-set.seed(123)
+set.seed(124)
 x <- rgamma(50, scale = 0.5, shape = 3)
 
 ## parametric family of probability measures
@@ -510,7 +512,7 @@ plot(profile(res))
 
 
 ###################################################
-### chunk number 54: NormApprox
+### code chunk number 54: NormApprox
 ###################################################
 require(distr)
 
@@ -524,7 +526,7 @@ NormApprox <- U12 - 6
 
 x <- seq(-4,4,0.001)
 
-opar <- par()
+opar <- par(no.readonly = TRUE)
 par(mfrow = c(2,1))
 
 plot(x, d(NormApprox)(x),
@@ -550,7 +552,7 @@ par(opar)
 
 
 ###################################################
-### chunk number 55: ConvolutionNormalDistr
+### code chunk number 55: ConvolutionNormalDistr
 ###################################################
 require(distr)
 
@@ -640,7 +642,7 @@ distroptions("TruncQuantile" = oldeps)
 
 
 ###################################################
-### chunk number 56: ComparisonFFTandRtoDPQ
+### code chunk number 56: ComparisonFFTandRtoDPQ
 ###################################################
 require(distr)
 
@@ -708,7 +710,7 @@ legend("topleft",
 
 
 ###################################################
-### chunk number 57: StationaryRegressorDistr
+### code chunk number 57: StationaryRegressorDistr
 ###################################################
 require(distr)
 
@@ -773,7 +775,7 @@ legend("topleft", legend=c("exact", "FFT"),
 ## quantile functions
 x <- seq(from = eps, to = 1-eps, length = 1000)
 plot(x, q(X)(x),type = "l", lwd = 5)
-lines(x , sapply(x,q(H)), col = "orange", lwd = 1)
+lines(x , q(H)(x), col = "orange", lwd = 1)
 title("Quantile functions")
 legend( "topleft", 
         legend=c("exact", "FFT"), 
@@ -815,7 +817,7 @@ distroptions("TruncQuantile" = oldeps)
 
 
 ###################################################
-### chunk number 58: destructive
+### code chunk number 58: destructive
 ###################################################
 ##########################################################
 ## Demo: Instructive destructive example
@@ -835,7 +837,7 @@ plot(N, lwd = 3)
 
 
 ###################################################
-### chunk number 59: SimulateandEstimate
+### code chunk number 59: SimulateandEstimate
 ###################################################
 require(distrTEst)
     ### also loads distrSim
@@ -864,7 +866,7 @@ plot(contsim)
 
 
 ###################################################
-### chunk number 60: elist
+### code chunk number 60: elist
 ###################################################
 require(distrTEst)
 psim <- function(theta,y,m0){
@@ -899,19 +901,19 @@ plot(elist, cex = 0.7, las = 2)
 
 
 ###################################################
-### chunk number 61: mest
+### code chunk number 61: mest
 ###################################################
 result.cont.mest
 
 
 ###################################################
-### chunk number 62: elist.summary
+### code chunk number 62: elist.summary
 ###################################################
 summary(elist)
 
 
 ###################################################
-### chunk number 63: Expectation
+### code chunk number 63: Expectation
 ###################################################
 require("distrEx")
 # Example
@@ -930,7 +932,7 @@ E(N, sq) - E(N, id)^2
 
 
 ###################################################
-### chunk number 64: nFoldConvolution
+### code chunk number 64: nFoldConvolution
 ###################################################
 ##########################################################
 ## Demo: n-fold convolution of absolutely continuous 
